@@ -10,6 +10,8 @@ import json
 import time
 from collections import OrderedDict
 from queue import Queue, Empty
+from urllib.parse import quote_plus
+
 from kafka import KafkaProducer
 from elasticsearch import Elasticsearch, helpers
 from threading import Lock, Thread
@@ -21,6 +23,12 @@ from concurrent_log_handler import ConcurrentRotatingFileHandler  # 需要安装
 
 from py_log import py_log_config_default
 from py_log import nb_print
+import hmac
+import base64
+import hashlib
+
+_ver = sys.version_info
+is_py3 = (_ver[0] == 3)
 
 very_nb_print = nb_print
 os_name = os.name
@@ -738,19 +746,37 @@ class CompatibleSMTPSSLHandler(handlers.SMTPHandler):
 class DingTalkHandler(logging.Handler):
     _lock_for_remove_handlers = Lock()
 
-    def __init__(self, ding_talk_token=None, time_interval=60):
+    def __init__(self, ding_talk_token=None, time_interval=60, at_mobiles=(), at_all: int = 0, show_code_line=True,
+                 secret=None):
         super().__init__()
-        self.ding_talk_token =ding_talk_token
+        self.ding_talk_token = ding_talk_token
         self._ding_talk_url = f'https://oapi.dingtalk.com/robot/send?access_token={ding_talk_token}'
         self._current_time = 0
         self._time_interval = time_interval  # 最好别频繁发。
+        self.start_time = time.time()
         self._lock = Lock()
+        self.at_mobiles = at_mobiles
+        self.at_all = at_all
+        self.show_code_line = show_code_line
+        self.secret = secret
+        if self.secret is not None and self.secret.startswith('SEC'):
+            self.update_webhook()
+
+    def update_webhook(self):
+        """
+        钉钉群自定义机器人安全设置加签时，签名中的时间戳与请求时不能超过一个小时，所以每个1小时需要更新签名
+        """
+        timestamp = round(self.start_time * 1000)
+        string_to_sign = '{}\n{}'.format(timestamp, self.secret)
+        hmac_code = hmac.new(self.secret.encode(), string_to_sign.encode(), digestmod=hashlib.sha256).digest()
+        sign = quote_plus(base64.b64encode(hmac_code))
+        self._ding_talk_url = '{}&timestamp={}&sign={}'.format(self._ding_talk_url, str(timestamp), sign)
 
     def emit(self, record):
         # from threading import Thread
         with self._lock:
             if time.time() - self._current_time > self._time_interval:
-                # very_nb_print(self._current_time)
+                # very_nb_print(self._ding_talk_url)
                 self._current_time = time.time()
                 self.__emit(record)
                 # Thread(target=self.__emit, args=(record,)).start()
@@ -759,9 +785,17 @@ class DingTalkHandler(logging.Handler):
                 very_nb_print(f' 此次离上次发送钉钉消息时间间隔不足 {self._time_interval} 秒，此次不发送这个钉钉内容： {record.msg}    ')
 
     def __emit(self, record):
-        message = self.format(record)
+        if self.show_code_line:
+            message = self.format(record)
+        else:
+            message = record.msg
         very_nb_print(message)
-        data = {"msgtype": "text", "text": {"content": message, "title": '这里的标题能起作用吗？？'}}
+        data = {"msgtype": "text", "text": {"content": message}, "at": dict()}
+        if self.at_all == 1:
+            data["at"]["isAtAll"] = 1
+        else:
+            if self.at_mobiles:
+                data["at"]['atMobiles'] = [mobile for mobile in self.at_mobiles]
         try:
             self._remove_urllib_hanlder()  # 因为钉钉发送也是使用requests实现的，如果requests调用的urllib3命名空间也加上了钉钉日志，将会造成循环，程序卡住。一般情况是在根日志加了钉钉handler。
             resp = requests.post(self._ding_talk_url, json=data, timeout=(5, 5))
@@ -775,12 +809,88 @@ class DingTalkHandler(logging.Handler):
 
     @classmethod
     def _remove_urllib_hanlder(cls):
-        for name in ['root','urllib3','requests']:
+        for name in ['root', 'urllib3', 'requests']:
             cls.__remove_urllib_hanlder_by_name(name)
 
     @classmethod
-    def __remove_urllib_hanlder_by_name(cls,logger_name):
+    def __remove_urllib_hanlder_by_name(cls, logger_name):
         with cls._lock_for_remove_handlers:
-            for index,hdlr in enumerate(logging.getLogger(logger_name).handlers):
+            for index, hdlr in enumerate(logging.getLogger(logger_name).handlers):
+                if 'DingTalkHandler' in str(hdlr):
+                    logging.getLogger(logger_name).handlers.pop(index)
+
+
+class WeChatHandler(logging.Handler):
+    _lock_for_remove_handlers = Lock()
+
+    def __init__(self, corpid=None, corpsecret=None, agentid=None, at_users=(), at_all: int = 0,
+                 show_code_line=True, time_interval=60,):
+        super().__init__()
+        self.corpid = corpid
+        self.corpsecret = corpsecret
+        self.agentid = agentid
+        self.at_users = at_users
+        self.at_all = at_all
+        self._time_interval = time_interval  # 最好别频繁发。
+        self._current_time = 0
+        self.start_time = time.time()
+        self._lock = Lock()
+        self.show_code_line = show_code_line
+
+    def emit(self, record):
+        # from threading import Thread
+        with self._lock:
+            if time.time() - self._current_time > self._time_interval:
+                self._current_time = time.time()
+                self.__emit(record)
+
+            else:
+                very_nb_print(f' 此次离上次发送企业消息时间间隔不足 {self._time_interval} 秒，此次不发送这个钉钉内容： {record.msg}    ')
+
+    def _get_wechat_token(self):
+        tokenUrl = "https://qyapi.weixin.qq.com/cgi-bin/gettoken"
+        values = {'corpid': self.corpid, 'corpsecret': self.corpsecret}
+        req = requests.post(tokenUrl, params=values)
+        data = json.loads(req.text)
+        very_nb_print(data)
+        return data["access_token"]
+
+    def __emit(self, record):
+        if self.show_code_line:
+            message = self.format(record)
+        else:
+            message = record.msg
+        very_nb_print(message)
+        url_pre = "https://qyapi.weixin.qq.com/cgi-bin/message/send?access_token="
+
+        url = url_pre + self._get_wechat_token()
+        if self.at_all == 0:
+            to_user = '|'.join(list(self.at_users))
+        elif self.at_all == 1:
+            to_user = '@all'
+        values = """{"touser" : "%s" ,
+                          "msgtype":"text",
+                          "agentid":"%s",
+                          "text":{
+                            "content": "%s"
+                          },
+                          "safe":"0"
+                          }""".format(to_user, self.agentid, message)
+        try:
+            self._remove_urllib_hanlder()
+            resp = requests.post(url, values)
+            very_nb_print(f'企业微信返回 ： {resp.text}')
+        except requests.RequestException as e:
+            very_nb_print(f"发送消息给企业微信失败 {e}")
+
+    @classmethod
+    def _remove_urllib_hanlder(cls):
+        for name in ['root', 'urllib3', 'requests']:
+            cls.__remove_urllib_hanlder_by_name(name)
+
+    @classmethod
+    def __remove_urllib_hanlder_by_name(cls, logger_name):
+        with cls._lock_for_remove_handlers:
+            for index, hdlr in enumerate(logging.getLogger(logger_name).handlers):
                 if 'DingTalkHandler' in str(hdlr):
                     logging.getLogger(logger_name).handlers.pop(index)
