@@ -174,7 +174,7 @@ class LogManager(object):
 
     # 加*是为了强制在调用此方法时候使用关键字传参，如果以位置传参强制报错，因为此方法后面的参数中间可能以后随时会增加更多参数，造成之前的使用位置传参的代码参数意义不匹配。
     # noinspection PyAttributeOutsideInit
-    default_log_path = sys.path[1]
+    default_log_path = sys.path[1] + "/logs"
 
     def get_logger_and_add_handlers(self, log_level_int: int = None, *, is_add_stream_handler=True,
                                     do_not_use_color_handler=None, log_path=default_log_path,
@@ -183,7 +183,12 @@ class LogManager(object):
                                     ding_talk_token=None, ding_talk_time_interval=60,
                                     mail_handler_config: MailHandlerConfig = MailHandlerConfig(),
                                     is_add_mail_handler=False,
-                                    formatter_template: int = None):
+                                    formatter_template: int = None,
+                                    at_mobiles=(),
+                                    at_all: int = 0,
+                                    show_code_line=True,
+                                    secret=None,
+                                    corpid=None, corpsecret=None, agentid=None, at_users=()):
         """
        :param log_level_int: 日志输出级别，设置为 1 2 3 4 5，分别对应原生logging.DEBUG(10)，logging.INFO(20)，logging.WARNING(30)，logging.ERROR(40),logging.CRITICAL(50)级别，现在可以直接用10 20 30 40 50了，兼容了。
        :param is_add_stream_handler: 是否打印日志到控制台
@@ -234,9 +239,16 @@ class LogManager(object):
         self._formatter = py_log_config_default.FORMATTER_DICT[formatter_template]
 
         self.logger.setLevel(self._logger_level)
+        self.at_mobiles = at_mobiles
+        self.at_all = at_all
+        self.show_code_line = show_code_line
+        self.secret = secret
+        self.corpid = corpid
+        self.corpsecret = corpsecret
+        self.agentid = agentid
+        self.at_users = ()
         self.__add_handlers()
-        # self.logger_name_list.append(self._logger_name)
-        # self.logger_list.append(self.logger)
+
         return self.logger
 
     def get_logger_without_handlers(self):
@@ -259,7 +271,7 @@ class LogManager(object):
         """
         if handler_class not in (
                 logging.StreamHandler, ColorHandler, MongoHandler, ConcurrentRotatingFileHandler, MongoHandler,
-                CompatibleSMTPSSLHandler, ElasticHandler, DingTalkHandler, KafkaHandler):
+                CompatibleSMTPSSLHandler, ElasticHandler, DingTalkHandler, KafkaHandler, WeChatHandler):
             raise TypeError('设置的handler类型不正确')
         for handler in self.logger.handlers:
             if isinstance(handler, handler_class):
@@ -329,13 +341,19 @@ class LogManager(object):
 
         # REMIND 添加钉钉日志。
         if not self._judge_logger_has_handler_type(DingTalkHandler) and self._ding_talk_token:
-            self.__add_a_hanlder(DingTalkHandler(self._ding_talk_token, self._ding_talk_time_interval))
+            self.__add_a_hanlder(
+                DingTalkHandler(self._ding_talk_token, self._ding_talk_time_interval, self.at_mobiles, self.at_all,
+                                self.show_code_line, self.secret))
+        # REMIND 添加微信日志。
+        if not self._judge_logger_has_handler_type(WeChatHandler) and self.corpid:
+            self.__add_a_hanlder(
+                WeChatHandler(self.corpid, self.corpsecret, self.agentid, self.at_users, self.at_all))
 
         if not self._judge_logger_has_handler_type(CompatibleSMTPSSLHandler) and self._is_add_mail_handler:
             self.__add_a_hanlder(CompatibleSMTPSSLHandler(**self._mail_handler_config.get_dict()))
 
 
-default_log_path = sys.path[1]
+default_log_path = sys.path[1] + '/logs'
 
 
 @lru_cache()  # LogManager 本身也支持无限实例化
@@ -345,7 +363,8 @@ def get_logger(name: str, *, log_level_int: int = None, is_add_stream_handler=Tr
                mongo_url=None, is_add_elastic_handler=False, is_add_kafka_handler=False,
                ding_talk_token=None, ding_talk_time_interval=60,
                mail_handler_config: MailHandlerConfig = MailHandlerConfig(), is_add_mail_handler=False,
-               formatter_template: int = None) -> logging.Logger:
+               formatter_template: int = None, at_mobiles=(), at_all=0, show_code_line=False,
+               secret=None, corpid=None, corpsecret=None, agentid=None, at_users=None) -> logging.Logger:
     """
     重写一遍，是为了更好的pycharm自动补全，所以不用**kwargs的写法。
     如果太喜欢函数调用了，可以使用这种
@@ -375,7 +394,6 @@ def get_logger(name: str, *, log_level_int: int = None, is_add_stream_handler=Tr
     """
     locals_copy = copy.copy(locals())
     locals_copy.pop('name')
-    # print(locals_copy)
     return LogManager(name).get_logger_and_add_handlers(**locals_copy)
 
 
@@ -458,156 +476,6 @@ class LoggerLevelSetterMixin:
         return self
 
 
-# noinspection PyMethodMayBeStatic,PyNestedDecorators,PyArgumentEqualDefault
-# class _Test(unittest.TestCase):
-#     # noinspection PyMissingOrEmptyDocstring
-#     @classmethod
-#     def tearDownClass(cls):
-#         """
-#
-#         """
-#         time.sleep(1)
-#
-#     @unittest.skip
-#     def test_repeat_add_handlers_(self):
-#         """测试重复添加handlers"""
-#         LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-#         LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-#         LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-#         test_log = LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-#         print('下面这一句不会重复打印四次和写入日志四次')
-#         time.sleep(1)
-#         test_log.debug('这一句不会重复打印四次和写入日志四次')
-#
-#     @unittest.skip
-#     def test_get_logger_without_hanlders(self):
-#         """测试没有handlers的日志"""
-#         log = LogManager('test2').get_logger_without_handlers()
-#         print('下面这一句不会被打印')
-#         time.sleep(1)
-#         log.info('这一句不会被打印')
-#
-#     @unittest.skip
-#     def test_add_handlers(self):
-#         """这样可以在具体的地方任意写debug和info级别日志，只需要在总闸处规定级别就能过滤，很方便"""
-#         LogManager('test3').get_logger_and_add_handlers(2)
-#         log1 = LogManager('test3').get_logger_without_handlers()
-#         print('下面这一句是info级别，可以被打印出来')
-#         time.sleep(1)
-#         log1.info('这一句是info级别，可以被打印出来')
-#         print('下面这一句是debug级别，不能被打印出来')
-#         time.sleep(1)
-#         log1.debug('这一句是debug级别，不能被打印出来')
-#
-#     @unittest.skip
-#     def test_only_write_log_to_file(self):  # NOQA
-#         """只写入日志文件"""
-#         log5 = LogManager('test5').get_logger_and_add_handlers(20)
-#         log6 = LogManager('test6').get_logger_and_add_handlers(is_add_stream_handler=False, log_filename='test6.log')
-#         print('下面这句话只写入文件')
-#         log5.debug('这句话只写入文件')
-#         log6.debug('这句话只写入文件')
-#
-#     @unittest.skip
-#     def test_none(self):
-#         # noinspection PyUnusedLocal
-#         log1 = LogManager('log1').get_logger_and_add_handlers()
-#         LogManager().get_logger_and_add_handlers()
-#
-#         LogManager().get_logger_and_add_handlers()
-#         log1 = LogManager('log1').get_logger_and_add_handlers()
-#         LogManager().get_logger_and_add_handlers()
-#         LogManager('log1').get_logger_and_add_handlers(log_filename='test_none.log')
-#         log1.debug('打印几次？')
-#
-#     @unittest.skip
-#     def test_formater(self):
-#         logger2 = LogManager('test_formater2').get_logger_and_add_handlers(formatter_template=6)
-#         logger2.debug('测试日志模板2')
-#         logger5 = LogManager('test_formater5').get_logger_and_add_handlers(formatter_template=5)
-#         logger5.error('测试日志模板5')
-#
-#     @unittest.skip
-#     def test_ding_talk(self):
-#         logger = LogManager('testdinding').get_logger_and_add_handlers(
-#             ding_talk_token=py_log_config_default.DING_TALK_TOKEN,
-#             ding_talk_time_interval=10)
-#         logger.debug('啦啦啦德玛西亚1')
-#         logger.debug('啦啦啦德玛西亚2')
-#         time.sleep(10)
-#         logger.debug('啦啦啦德玛西亚3')
-#
-#     @unittest.skip
-#     def test_remove_handler(self):
-#         logger = LogManager('test13').get_logger_and_add_handlers()
-#         logger.debug('去掉coloerhandler前')
-#         LogManager('test13').remove_handler_by_handler_class(ColorHandler)
-#         logger.debug('去掉coloerhandler后，此记录不会被打印')
-#
-#     @unittest.skip
-#     def test_logging(self):
-#         # logging命名空间是root,会导致日志重复打印，不要直接用。
-#         logger = LogManager('test14').get_logger_and_add_handlers(formatter_template=4)
-#         logger.debug('xxxx')
-#         logging.warning('yyyyyyy')
-#         logger.warning('zzzzzzzzz')
-#
-#     @unittest.skip
-#     def test_logger_level_setter_mixin(self):
-#         """
-#         测试可以设置日志级别的mixin类
-#         :return:
-#         """
-#         print('测试非常流弊的print')
-#
-#         class A(LoggerMixin, LoggerLevelSetterMixin):
-#             pass
-#
-#         a = A().set_log_level(20)
-#         a.logger.debug('这句话不能被显示')  # 这句话不能被打印
-#         a.logger.error('这句话可以显示')
-#
-#     # @unittest.skip
-#     def test_color_and_mongo_hanlder(self):
-#         """测试彩色日志和日志写入mongodb"""
-#         very_nb_print('测试颜色和mongo')
-#
-#         # logger = LogManager('helloMongo', is_pycharm_2019=False).get_logger_and_add_handlers(mongo_url=app_config.connect_url, formatter_template=5)
-#         logging.error('xxxx')
-#         logger = LogManager('helloMongo').get_logger_and_add_handlers(formatter_template=5, is_add_elastic_handler=True)
-#         logger.addHandler(ColorHandler())  # 由于打了强大的猴子补丁，无惧反复添加同种handler。
-#         logger.addHandler(ColorHandler())
-#         logger.addHandler(ColorHandler())
-#         for i in range(1000000):
-#             time.sleep(0.1)
-#             logger.debug('一个debug级别的日志。' * 3)
-#             logger.info('一个info级别的日志。' * 3)
-#             logger.warning('一个warning级别的日志。' * 3)
-#             logger.error('一个error级别的日志。' * 3)
-#             logger.critical('一个critical级别的日志。' * 3)
-#
-#     @unittest.skip
-#     def test_all_handlers(self):
-#         logger = LogManager('hi').get_logger_and_add_handlers(log_filename='hi.log',
-#                                                               ding_talk_token=py_log_config_default.DING_TALK_TOKEN,
-#                                                               mongo_url=py_log_config_default.MONGO_URL,
-#                                                               formatter_template=5)
-#         logger.debug('测试多种handler')
-
-
-# def test_multiprocess_file_handler():
-#     t1 = time.time()
-#     logger = LogManager('abcd').get_logger_and_add_handlers(is_add_stream_handler=False,
-#                                                             log_filename='amulti_test99.log', log_file_size=200)
-#     for i in range(1000000, 2000000):
-#         # time.sleep(0.000001)
-#         logger.debug(f'{i}a')
-#         if i % 10000 == 0:
-#             very_nb_print(i)
-#     very_nb_print(time.time() - t1)
-#     time.sleep(10)
-
-
 if __name__ == "__main__":
     print(123456)
     logger = LogManager('test14').get_logger_and_add_handlers(formatter_template=5)
